@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = 'v0.202.2';
+our $VERSION = 'v0.203.0';
 
 
 use Role::Declare -lax;
@@ -17,11 +17,6 @@ use Types::Common::Numeric qw/PositiveNum PositiveOrZeroNum/;
 use namespace::clean;
 
 
-instance_method get_context(
-) :Return(SpanContext) {}
-
-
-
 instance_method overwrite_operation_name(
     Str $operation_name
 ) :ReturnSelf {}
@@ -72,15 +67,4 @@ instance_method add_baggage_items(
 
 
 
-instance_method get_baggage_item(
-    Str $key
-) :ReturnMaybe(Value) {}
-
-
-
-instance_method get_baggage_items(
-) :ReturnList(Any) {}
-
-
-
 1;
